import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * Das Symbol des Schlangenkopfs.
 *
 * @author Albert Wiedemann
 * @version 1.0
 */
class KopfSymbol extends Actor
{
    /** x-Position */
    int x;
    /** y-Position */
    int y;
    /** Blickrichtung */
    char ausrichtung;

    /**
     * Standardkonstruktor für Objekte der Klasse KopfSymbol.
     * Er erzeugt ein Kopfsymbol an Postion (0 | 0).
     */
    KopfSymbol()
    {
        ausrichtung = 'O';
        x = 0;
        y = 0;
        setLocation(13, 10);
        setRotation(0);
    }
    
    /**
     * Setzt die Position der Mitte des Symbols.
     * @param x x-Position der Mitte
     * @param y y-Position der Mitte
     */
    @Override public void setLocation(int x, int y)
    {
        this.x = x - 13;
        this.y = y - 10;
        super.setLocation(x, y);
    }
    
    /**
     * Setzt den Winkel des Kopfs auf 'O', 'S', 'W' oder 'N'
     * Die Winkelangabe ist in Grad, positive Werte drehen im Uhrzeigersinn,
     * negative Werte drehen gegen den Uhrzeigersinn (mathematisch negativer Drehsinn).
     * @param winkel der (neue) Drehwinkel des Dreiecks
     */
    @Override public void setRotation(int w)
    {
        if ((45 <= w) && (w < 135))
        {
            ausrichtung = 'S';
            super.setRotation(90);
        }
        else if ((135 <= w) && (w < 225))
        {
            ausrichtung = 'W';
            super.setRotation(180);
        }
        else if ((225 <= w) && (w < 315))
        {
            ausrichtung = 'N';
            super.setRotation(270);
        }
        else
        {
            ausrichtung = 'W';
            super.setRotation(0);
        }
    }

    /**
     * Setzt die Position des Kopfelements.Der Ursprung liegt in der Mitte des
     * Fensters, die y-Achse zeigt nach unten.(x /y) bedeutet das
     * Kästchen rechts unterhalb der Gitterlinien.
     * @param x x-Position
     * @param y y-Position
     */
    void PositionSetzen(int x, int y)
    {
        this.x = x;
        this.y = y;
        super.setLocation(x + 13, y + 10);
    }

    /**
     * Gibt den X-Wert der Position des Kopfelements.
     * @return x-Position
     */
    int XPositionGeben()
    {
        return x;
    }

    /**
     * Gibt den Y-Wert der Position des Kopfelements.
     * @return y-Position
     */
    int YPositionGeben()
    {
        return y;
    }

    /**
     * Setzt die Ausrichtung des Kopfelements.
     * @param ausrichtung Ausrichtung des Kopfelements.
     */
    void AusrichtungSetzen(char ausrichtung)
    {
        this.ausrichtung = ausrichtung;
        switch (ausrichtung)
        {
          case 'S':
            super.setRotation(90);
            break;
          case 'W':
            super.setRotation(180);
            break;
          case 'N':
            super.setRotation(270);
            break;
          case 'O':
            super.setRotation(0);
            break;
        }
    }

    /**
     * Setzt die Ausrichtung des Kopfelements.
     * @eturn Ausrichtung des Kopfelements.
     */
    char AusrichtungGeben()
    {
        return ausrichtung;
    }
    
    /**
     * Entfernt die Figur aus der Anzeige
     */
    void Entfernen()
    {
        getWorld().removeObject(this);
    }
}
